@@ -56,7 +56,7 @@ class Benutzerverwaltung(IDMRequest):
             raise UnexpectedJsonError(resp.text)
 
     def update_user(
-        self, user: ChangeTemplate, update_dict: dict[str, str | list[str]]
+        self, user: ChangeTemplate, update_dict: dict[str, str | list[str] | None]
     ) -> ChangeTemplate:
         request_url: str = f"{self.api_url}{self.api_suffix}/{user.id}"
         resp: "Response"
