@@ -60,10 +60,14 @@ class ChangeTemplate(pydantic.BaseModel):
     goesternUserStatus: str = None
 
     @staticmethod
-    def update_json(name: str, value: str | list[str]) -> str:
+    def update_json(name: str, value: str | list[str] | None) -> str:
+        if value is not None:
+            value = [value] if not isinstance(value, list) else value
+        else:
+            value = []
         data = {
             "name": name,
-            "value": [value] if not isinstance(value, list) else value,
+            "value": value,
         }
         return json.dumps({"attributes": [data]})
 
